@@ -508,10 +508,30 @@ class ipv6Validate extends AbstractValidate {
         if ($ret === false) {
             return false;
         }
-
+/*
         if(preg_match('/::$/',$val)){
             return false;
         }
+*/
+
+        return true;
+    }
+}
+
+/*************************************************************************
+* Class          : ipv6PoolValidate
+* Description    : Validation class that ipv6 address
+* args           : $val     - validate values
+*                : $options - method options
+* return         : true or false
+*************************************************************************/
+class ipv6PoolValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        $ret = filter_var($val, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6);
+        if ($ret === false) {
+            return false;
+        }
 
         return true;
     }
@@ -901,3 +921,74 @@ class uniqintableValidate extends AbstractValidate {
         return true;
     }
 }
+
+/************************************************************************* 
+* Class          : sharednameValidate
+* Description    : Validation class that sharedname
+* args           : $val     - validate values
+*                : $options - method options
+* return         : true or false
+*************************************************************************/
+class sharednameValidate extends AbstractValidate {
+    public function run($val, $option = array(""))
+    {
+        $len = strlen($val);
+        if ($len > 256) {
+            return false;
+        }
+
+        if ($len !== strspn($val, 'abcdefghijklmnopqrstuvwxyz'.
+                                  'ABCEDFGHIJKLMNOPQRSTUVWXYZ'.
+                                  '1234567890-_.')) {
+            return false;
+        }
+
+        return true;
+    }
+}
+
+/*****************************************************************************
+* Class          : greateripv4Validate
+* Description    : Validation class that ip greater than other ip
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class greateripv4Validate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        /* make str for startpool */
+        $start = implode(":", $option);
+
+        $start_long = ip2long($start); 
+        $end_long = ip2long($val);
+        if ($end_long < $start_long) {
+            return false;
+        }
+
+        return true;
+    }
+}
+
+/*****************************************************************************
+ * Class          : greateripv6Validate
+ * Description    : Validation class that ip greater than other ip
+ * args           : $val
+ *                : $options - method options
+ * return         : true or false
+ *****************************************************************************/
+class greateripv6Validate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        /* make str for startpool */
+        $start = implode(":", $option);
+
+        $start_ip = inet_pton($start);
+        $end_ip   = inet_pton($val);
+        if ($end_ip < $start_ip) {
+            return false;
+        }
+
+        return true;
+    }
+}
