@@ -47,7 +47,7 @@ class v6typeValidate extends AbstractValidate {
 class subnetinconf4Validate extends AbstractValidate {
     public function run($val, $option = array())
     {
-        $conf = new KeaConf();
+        $conf = new KeaConf(DHCPV4);
         $ret = $conf->check_subnet4($val);
         if ($ret === false) {
             return false;
@@ -66,7 +66,7 @@ class subnetinconf4Validate extends AbstractValidate {
 class subnetinconf6Validate extends AbstractValidate {
     public function run($val, $option = array())
     {
-        $conf = new KeaConf();
+        $conf = new KeaConf(DHCPV6);
         $ret = $conf->check_subnet6($val);
         if ($ret === false) {
             return false;
@@ -242,7 +242,7 @@ class outpoolValidate extends AbstractValidate {
     {
         $subnet = $option[0];
 
-        $conf = new KeaConf();
+        $conf = new KeaConf(DHCPV4);
         $pools = $conf->get_pools($subnet);
 
         /* Returns true if there is no pool */
@@ -251,7 +251,7 @@ class outpoolValidate extends AbstractValidate {
         }
 
         foreach ($pools as $pool) {
-            list($min, $max) = explode(' - ', $pool['pool']);
+            list($min, $max) = explode('-', $pool['pool']);
 
             $ip_long  = ip2long($val);
             $min_long = ip2long($min);
@@ -279,7 +279,7 @@ class outpool_delegate6Validate extends AbstractValidate {
         $prefix = array_pop($option);
         $subnet = implode(":", $option);
 
-        $conf = new KeaConf();
+        $conf = new KeaConf(DHCPV6);
         $pools = $conf->get_pools6($subnet);
 
         /* Returns true if there is no pool */
@@ -288,7 +288,7 @@ class outpool_delegate6Validate extends AbstractValidate {
         }
 
         foreach ($pools as $pool) {
-            list($min, $max) = explode(' - ', $pool['pool']);
+            list($min, $max) = explode('-', $pool['pool']);
 
             /* Convert hexadecimal number to binary number */
             $val_addr = inet_pton($val);
@@ -330,7 +330,7 @@ class outpool_delegate6Validate extends AbstractValidate {
 class outpool6Validate extends AbstractValidate {
     public function run($val, $option = array())
     {
-        $conf = new KeaConf();
+        $conf = new KeaConf(DHCPV6);
         $subnet = implode(":", $option);
         $pools = $conf->get_pools6($subnet);
 
@@ -344,7 +344,7 @@ class outpool6Validate extends AbstractValidate {
 
         foreach ($pools as $pool) {
 
-            list($min, $max) = explode(' - ', $pool['pool']);
+            list($min, $max) = explode('-', $pool['pool']);
 
             /* Check the format of the pool */
             $ret = filter_var($min, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6);
@@ -715,3 +715,472 @@ class duplicate_delegate6Validate extends AbstractValidate {
         return true;
     }
 }
+
+/*****************************************************************************
+* Class          : subnet4formatValidate
+* Description    : check format of subnet4
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class subnet4formatValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        $arr_item = explode('/', $val);
+        if (count($arr_item) !=  2) {
+            return false;
+        }
+
+        /* check ipaddress */
+        $ret = filter_var($arr_item[0], FILTER_VALIDATE_IP);
+        if ($ret === false) {
+            return false;
+        }
+   
+        /* check netmask */
+        if (!chec_str($arr_item[1], "0123456789")) {
+            return false;
+        }
+
+        if ($arr_item[1] < 1 || $arr_item[1] > 32) {
+            return false;
+        }
+
+        return true;
+    }
+}
+
+/*****************************************************************************
+* Class          : subnet6formatValidate
+* Description    : check format of subnet6
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class subnet6formatValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        $arr_item = explode('/', $val);
+        if (count($arr_item) !=  2) {
+            return false;
+        }
+
+        /* check ipaddress */
+        $ret = filter_var($arr_item[0], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6);
+        if ($ret === false) {
+            return false;
+        }
+
+        /* check netmask */
+        if (!chec_str($arr_item[1], "0123456789")) {
+            return false;
+        }
+
+        if ($arr_item[1] < 1 || $arr_item[1] > 128) {
+            return false;
+        }
+
+        return true;
+    }
+}
+
+/*****************************************************************************
+ * Class          : subnet4existValidate
+ * Description    : check subnet4 overlap with other subnet in config
+ * args           : $val
+ *                : $options - method options
+ * return         : true or false
+ *****************************************************************************/
+class subnet4existValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        /* create config */
+        $conf = new KeaConf(DHCPV4);
+
+        if (isset($option[0]) && ($option[0] === 'exist_true')) {
+            $exist_true = true;
+        }
+
+        /* get subnet part only */
+        $conf_all_subnet = $conf->mk_arr_all_subnet($conf->dhcp4);
+
+        foreach ($conf_all_subnet as $conf_subnet) {
+            /* loop all subnet */
+            foreach ($conf_subnet as $one_subnet) {
+
+                /* if existed subnet in config */
+                if (isset($one_subnet[STR_SUBNET])) {
+                    /* if subnet exist*/
+                    if ($val === $one_subnet[STR_SUBNET]) {
+                        return true;
+                    }
+                }
+            }
+        }
+        return false;
+    }
+}
+
+/*****************************************************************************
+ * Class          : subnet6existValidate
+ * Description    : check subnet4 overlap with other subnet in config
+ * args           : $val
+ *                : $options - method options
+ * return         : true or false
+ *****************************************************************************/
+class subnet6existValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        /* create config */
+        $conf = new KeaConf(DHCPV6);
+
+        if (isset($option[0]) && ($option[0] === 'exist_true')) {
+            $exist_true = true;
+        }
+
+        /* get subnet part only */
+        $conf_all_subnet = $conf->mk_arr_all_subnet($conf->dhcp6);
+
+        foreach ($conf_all_subnet as $conf_subnet) {
+            /* loop all subnet in config */
+            foreach ($conf_subnet as $one_subnet) {
+                /* if existed subnet */
+                if (isset($one_subnet[STR_SUBNET])) {
+                    if ($val === $one_subnet[STR_SUBNET]) {
+                        return true;
+                    }
+                }
+            }
+        }
+        return false;
+    }
+}
+
+/*****************************************************************************
+* Class          : subnetoverldap4Validate
+* Description    : check subnet4 overlap with other subnet in config
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class subnetoverldap4Validate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        /* create config */
+        $conf = new KeaConf(DHCPV4);
+
+        if (isset($option[0]) && ($option[0] === 'exist_true')) {
+            $exist_true = true;
+        }
+
+        /* get subnet part only */
+        $conf_all_subnet = $conf->mk_arr_all_subnet($conf->dhcp4);
+
+        /* get range ip of this subnet */
+        list($val_min_str, $val_max_str)  = get_range_ipaddr_v4($val);
+        $val_min_long = ip2long($val_min_str);
+        $val_max_long = ip2long($val_max_str);
+
+        foreach ($conf_all_subnet as $shnet => $conf_subnet) {
+            /* loop in subnet config */
+            foreach ($conf_subnet as $one_subnet) {
+
+                /* if existed subnet */
+                if (isset($one_subnet[STR_SUBNET])) {
+ 
+                    /* get range ip of this subnet */
+                    list($conf_min_str, $conf_max_str) = 
+                          get_range_ipaddr_v4($one_subnet[STR_SUBNET]);
+    
+                    $conf_min_long = ip2long($conf_min_str);
+                    $conf_max_long = ip2long($conf_max_str);
+
+                    /* subnet overlap with other subnet */
+                    if ((($val_min_long >= $conf_min_long) &&
+                         ($conf_max_long <= $conf_max_str)) ||
+                        (($val_max_long >= $conf_min_long) &&
+                         ($val_max_long <= $conf_max_long))) {
+                        return false;
+                    }
+                }
+            }
+        }
+        return true;
+    }
+}
+
+/*****************************************************************************
+* Class          : subnetoverldap6Validate
+* Description    : check subnet6 overlap with other subnet in config
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class subnetoverldap6Validate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        /* create config */
+        $conf = new KeaConf(DHCPV6);
+
+        /* get subnet part only */
+        $conf_all_subnet = $conf->mk_arr_all_subnet($conf->dhcp6);
+
+        /* calculate range of subnet want checkt */
+        list($in_addr, $in_postPrefix) = explode('/', $val);
+        $in_binPrefix = $this->masktobyte($in_postPrefix);
+        $in_ip_min = inet_pton($in_addr);
+        $in_ip_max = inet_pton($in_addr) | ~$in_binPrefix;
+
+        foreach ($conf_all_subnet as $shnet => $conf_subnet) {
+
+            /* loop all subnet in config */
+            foreach ($conf_subnet as $one_subnet) {
+
+                /* calculate range of subnet in config */
+                list($sub_addr, $sub_postPrefix) = explode('/', $one_subnet[STR_SUBNET]);
+                $sub_binPrefix = $this->masktobyte($sub_postPrefix);
+                $sub_addr_min = inet_pton($sub_addr);
+                $sub_addr_max = inet_pton($sub_addr) | ~$sub_binPrefix;
+    
+                /* if do not overlap then continue */
+                if ((($in_ip_min >= $sub_addr_min) && ($in_ip_min <= $sub_addr_max)) ||
+                     (($in_ip_max >= $sub_addr_min) && ($in_ip_max <= $sub_addr_max))) {
+                    return false;
+                }
+            }
+        }
+
+        return true;
+    }
+}
+
+/*****************************************************************************
+* Class          : ipv4overlapValidate
+* Description    : check ipv4 overlap with pools in config
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class ipv4overlapValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        /* current pool */
+        $editing_pool = null;
+        if (isset($option[0])) {
+            $editing_pool = $option[0];
+        }
+
+        $val_long = ip2long($val);
+
+        /* create config */
+        $conf = new KeaConf(DHCPV4);
+
+        /* get subnet part only */
+        $conf_all_subnet = $conf->mk_arr_all_subnet($conf->dhcp4);;
+
+        /* loop all subnet in config */
+        foreach ($conf_all_subnet as $shname => $conf_subnet) {
+            foreach ($conf_subnet as $one_subnet) {
+
+                /* if subnet have pools */
+                if (isset($one_subnet[STR_POOLS])) {
+                    /* loop all pools in the subnet */
+                    foreach ($one_subnet[STR_POOLS] as $one_pool) {
+                        if (isset($one_pool[STR_POOL])) {
+
+                            /* get pool of config */ 
+                            list($conf_pool_min, $conf_pool_max) =
+                                  get_kea_pool_v4($one_pool[STR_POOL]);
+
+                            if (($editing_pool === $conf_pool_min) || 
+                                ($editing_pool === $conf_pool_max)) {
+                                continue;
+                            }
+
+                            $conf_min_long = ip2long($conf_pool_min);
+                            $conf_max_long = ip2long($conf_pool_max);
+
+                             /* check new pool */
+                            if (($val_long >= $conf_min_long) &&
+                                  ($val_long <= $conf_max_long)) {
+                                return false;
+                            }
+                        }
+                    }
+                }
+            }
+        }
+
+        return true;
+    }
+}
+
+/*****************************************************************************
+ * Class          : ipv6overlapValidate
+ * Description    : check ipv6 overlap with other pools in config
+ * args           : $val
+ *                : $options - method options
+ * return         : true or false
+ *****************************************************************************/
+class ipv6overlapValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        $editing_pool = null;
+        if (isset($option[0])) {
+            $editing_pool = implode(":", $option);
+            if ($editing_pool === false) {
+                return false;
+            }
+        }
+
+        $val = inet_pton($val);
+
+        /* create config */
+        $conf = new KeaConf(DHCPV6);
+
+        /* get subnet part only */
+        $conf_all_subnet = $conf->mk_arr_all_subnet($conf->dhcp6);;
+
+        /* loop all subnets in config */
+        foreach ($conf_all_subnet as $shname => $conf_subnet) {
+            foreach ($conf_subnet as $one_subnet) {
+                /* if subnet have pool  */
+                if (isset($one_subnet[STR_POOLS])) {
+                    foreach ($one_subnet[STR_POOLS] as $one_pool) {
+                        if (isset($one_pool[STR_POOL])) {
+
+                            list($conf_pool_min, $conf_pool_max) =
+                                  get_kea_pool_v6($one_pool[STR_POOL]);
+
+                            /* if pool is editting pool then next */
+                            if (($editing_pool === $conf_pool_min) || 
+                                 ($editing_pool === $conf_pool_max)) {
+                                continue;
+                            }
+
+                            $min = inet_pton($conf_pool_min);
+                            $max = inet_pton($conf_pool_max);
+                            /* Compare addresses */
+                            if ($val >= $min && $val <= $max) {
+                                return false;
+                            }
+                        }
+                    }
+                }
+            }
+        }
+
+        return true;
+    }
+}
+
+/*****************************************************************************
+* Class          : shared4existValidate
+* Description    : check shared4 overlap with other shared in config
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class shared4existValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        $exist_flg = false;
+        $exist_true = false;
+
+        /* create config */
+        $conf = new KeaConf(DHCPV4);
+
+        /* no change shared_name */
+        if (isset($option[0]) && isset($option[1]) &&
+                                 ($option[0] === $option[1])) {
+            return true;
+        }
+
+        /* exist is true */
+        if (isset($option[0]) && ($option[0] === 'exist_true')) {
+            $exist_true = true;
+        }
+
+        /* get shared part only */
+        $conf_shared = $conf->get_shared_part();
+
+
+        /* loop all shared in config */
+        foreach ($conf_shared as $one_shared) {
+
+            /* if existed shared */
+            if (isset($one_shared[STR_NAME])) {
+ 
+                /* shared-network overlap with other shared-network */
+                if ($val === $one_shared[STR_NAME]) {
+                    $exist_flg = true;
+                    break;
+                }
+            }
+        }
+
+        /* exist is true  */
+        if ($exist_true) {
+            return $exist_flg;
+
+        /* exist is false  */
+        } else {
+            return !$exist_flg;
+        }
+    }
+}
+/*****************************************************************************
+* Class          : shared6existValidate
+* Description    : check shared6 overlap with other shared in config
+* args           : $val
+*                : $options - method options
+* return         : true or false
+*****************************************************************************/
+class shared6existValidate extends AbstractValidate {
+    public function run($val, $option = array())
+    {
+        $exist_flg = false;
+        $exist_true = false;
+
+        /* create config */
+        $conf = new KeaConf(DHCPV6);
+
+        /* no change shared_name */
+        if (isset($option[0]) && isset($option[1]) && 
+                                 ($option[0] === $option[1])) {
+            return true;
+        }
+
+        /* exist is true */
+        if (isset($option[0]) && ($option[0] === 'exist_true')) {
+            $exist_true = true;
+        }
+
+        /* get shared part only */
+        $conf_shared = $conf->get_shared_part();
+
+
+        /* loop all shared in config */
+        foreach ($conf_shared as $one_shared) {
+
+            /* if existed shared */
+            if (isset($one_shared[STR_NAME])) {
+
+                /* shared-network overlap with other shared-network */
+                if ($val === $one_shared[STR_NAME]) {
+                    $exist_flg = true;
+                    break;
+                }
+            }
+        }
+
+        /* exist is true  */
+        if ($exist_true) {
+            return $exist_flg;
+
+        /* exist is false  */
+        } else {
+            return !$exist_flg;
+        }
+    }
+}
