@@ -60,6 +60,7 @@ class AddHost4
                           'e_dhcp4_boot_file_name' => null,
                           'e_tftp_server_name'     => null,
                           'e_boot_file_name'       => null,
+                          'is_show_warn_msg'       => 0,
                           'success'                => null];
 
         $this->err_tag = ['e_subnet'    => null,
@@ -69,7 +70,7 @@ class AddHost4
 
         $this->store = $store;
 
-        $this->conf = new KeaConf();
+        $this->conf = new KeaConf(DHCPV4);
         if ($this->conf->result === false) {
             $this->err_tag = array_merge($this->err_tag, $this->conf->err);
             $this->store->log->log($this->conf->err['e_log'], null);
@@ -93,6 +94,12 @@ class AddHost4
             $this->store->log->log($this->conf->err['e_log'], null);
             $this->check_subnet = false;
         }
+
+        /* check history in session */
+        $history = $this->conf->get_hist_from_sess();
+        if ($history !== NULL) {
+            $this->msg_tag['is_show_warn_msg'] = 1;
+        }
     }
 
     /*************************************************************************
