@@ -57,6 +57,7 @@ class AddHost6
                           'e_prefix'               => null,
                           'e_type'                 => null,
                           'checked'                => null,
+                          'is_show_warn_msg'       => 0,
                           'success'                => null];
 
         $this->err_tag = ['e_subnet'    => null,
@@ -66,7 +67,7 @@ class AddHost6
 
         $this->store = $store;
 
-        $this->conf = new KeaConf();
+        $this->conf = new KeaConf(DHCPV6);
         if ($this->conf->result === false) {
             $this->err_tag = array_merge($this->err_tag, $this->conf->err);
             $this->store->log->log($this->conf->err['e_log'], null);
@@ -89,6 +90,12 @@ class AddHost6
             $this->err_tag['e_msg'] = $this->conf->err['e_msg'];
             $this->store->log->log($this->conf->err['e_log'], null);
         }
+
+        /* check history in session */
+        $history = $this->conf->get_hist_from_sess();
+        if ($history !== NULL) {
+            $this->msg_tag['is_show_warn_msg'] = 1;
+        }
     }
 
     /*************************************************************************
