@@ -48,16 +48,23 @@ class BulkHost6
         $this->msg_tag = ['success'                => null,
                           'disp_msg'               => null,
                           'e_msg'                  => null];
+        $this->is_show_warn_msg = 0;
 
         $this->store = $store;
 
-        $this->conf = new KeaConf();
+        $this->conf = new KeaConf(DHCPV6);
         if ($this->conf->result === false) {
             $this->msg_tag = array_merge($this->msg_tag, $this->conf->err);
             $this->store->log->log($this->conf->err['e_log'], null);
             $this->check_conf = false;
             return;
         }
+
+        /* check history in session */
+        $history = $this->conf->get_hist_from_sess();
+        if ($history !== NULL) {
+            $this->is_show_warn_msg = 1;
+        }
     }
 
     /*************************************************************************
@@ -1041,6 +1048,7 @@ class BulkHost6
         $this->store->view->assign("pre", $this->pre);
         $this->store->view->assign("csverr", $this->csv_err);
         $this->store->view->assign("exist", $this->exist);
+        $this->store->view->assign("is_show_warn_msg", $this->is_show_warn_msg);
         $this->store->view->render("bulkhost6.tmpl", $this->msg_tag);
     }
 }
