@@ -101,6 +101,7 @@ class EditHost4
                           'code_3'                 => null,
                           'code_66'                => null,
                           'code_67'                => null,
+                          'is_show_warn_msg'       => 0,
                           'success'                => null];
 
         $this->err_tag = ['disp_msg'    => null,
@@ -112,7 +113,7 @@ class EditHost4
 
         $this->store = $store;
 
-        $this->conf = new KeaConf();
+        $this->conf = new KeaConf(DHCPV4);
         if ($this->conf->result === false) {
             $this->err_tag = array_merge($this->err_tag, $this->conf->err);
             $this->store->log->log($this->conf->err['e_log'], null);
@@ -137,6 +138,12 @@ class EditHost4
             $this->check_subnet = false;
             return;
         }
+
+        /* check history in session */
+        $history = $this->conf->get_hist_from_sess();
+        if ($history !== NULL) {
+            $this->msg_tag['is_show_warn_msg'] = 1;
+        }
     }
 
     /*************************************************************************
