@@ -220,7 +220,7 @@ class SearchHost4 {
     **************************************************************************/
     public function read_keaconf()
     {
-        $this->conf = new KeaConf(); 
+        $this->conf = new KeaConf(DHCPV4); 
         /* If an error is found by checking keaconf */
         if ($this->conf->result === false) {
 
@@ -243,25 +243,32 @@ class SearchHost4 {
     public function check_keaconf($params)
     {
         /* When reading of keaconf succeeded */
-        foreach ($this->conf->dhcp4['subnet4'] as $one) {
+        /* get all subnet in config */
+        $all_subnet_data = $this->conf->mk_arr_all_subnet($this->conf->dhcp4);
 
-            if (array_key_exists('id', $one) &&
+        foreach ($all_subnet_data as $shnet_name => $data_subnet) {
+
+            /* When reading of keaconf succeeded */
+            foreach ($data_subnet as $one) {
+
+                if (array_key_exists('id', $one) &&
                                          $one['id'] == $params['subnet_id']) {
-                /* When matching subnet_id is in keaconf */
-                if (array_key_exists('subnet', $one)) {
-                    if ($one['subnet'] == $params['subnet']) {
+                    /* When matching subnet_id is in keaconf */
+                    if (array_key_exists('subnet', $one)) {
+                        if ($one['subnet'] == $params['subnet']) {
 
-                        /* When a matching subnet is in keaconf */
-                        return true;
+                            /* When a matching subnet is in keaconf */
+                            return true;
+                        }
                     }
-                }
-                /* When matching subnet is not in keaconf */
-                $tmp_msg = _("No such subnet(%s)");
-                $this->msg_tag['disp_msg'] = sprintf($tmp_msg, $params['subnet']);
-                $this->store->log->output_log("No such subnet(" . $params['subnet'] . ")");
-                $this->display();
+                    /* When matching subnet is not in keaconf */
+                    $tmp_msg = _("No such subnet(%s)");
+                    $this->msg_tag['disp_msg'] = sprintf($tmp_msg, $params['subnet']);
+                    $this->store->log->output_log("No such subnet(" . $params['subnet'] . ")");
+                    $this->display();
 
-                return false;
+                    return false;
+                }
             }
         }
 
