@@ -92,7 +92,7 @@ class SearchHost6 {
         $this->store  = $store;
 
         /* read keaconf */
-        $this->conf = new KeaConf();
+        $this->conf = new KeaConf(DHCPV6);
         if ($this->conf->result === false) {
             $this->msg_tag['disp_msg'] = $this->conf->err['e_msg'];
             $this->store->log->output_log($this->conf->err['e_log']);
